==> seedsui-react-5.5.92.tgz: package/lib/Container/ContainerPull/BottomError.js <==
var _excluded = ["children"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useContext } from 'react';
import Context from "./../../Context/instance.js";
var BottomError = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var children = _ref.children,
      others = _objectWithoutProperties(_ref, _excluded);

  // context
  var context = useContext(Context) || {};

  var locale = context.locale || function (remark) {
    return remark || '';
  };

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  return /*#__PURE__*/React.createElement("div", _extends({
    ref: rootRef,
    className: "SID-Dragrefresh-ErrorContainer containerpull-pull",
    style: {
      height: '50px'
    }
  }, others), !children && /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-box"
  }, /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-caption"
  }, locale('加载失败, 请稍后再试', 'refreshing_failed'))), children);
});
export default BottomError;

==> seedsui-react-5.6.52.tgz: package/lib/Container/ContainerPull/BottomError.js <==
var _excluded = ["children"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useContext } from 'react';
import Context from "./../../Context/instance.js";
var BottomError = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var children = _ref.children,
      others = _objectWithoutProperties(_ref, _excluded);

  // context
  var context = useContext(Context) || {};

  var locale = context.locale || function (remark) {
    return remark || '';
  };

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  return /*#__PURE__*/React.createElement("div", _extends({
    className: "SID-Dragrefresh-ErrorContainer containerpull-pull",
    style: {
      height: '50px'
    }
  }, others, {
    ref: rootRef
  }), !children && /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-box"
  }, /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-caption"
  }, locale('加载失败, 请稍后再试', 'refreshing_failed'))), children);
});
export default BottomError;
